@@ -1,200 +1,19 @@
 #include <TMB.hpp>
 #include "init.h"
+#include "distrib.h"
+
 // don't need to include omp.h; we get it via TMB.hpp
 
-
-
 namespace glmmtmb{
-  template<class Type>
-  Type dbetabinom(Type y, Type a, Type b, Type n, int give_log=0)
-  {
-    /*
-      Wikipedia:
-      f(k|n,\alpha,\beta) =
-      \frac{\Gamma(n+1)}{\Gamma(k+1)\Gamma(n-k+1)}
-      \frac{\Gamma(k+\alpha)\Gamma(n-k+\beta)}{\Gamma(n+\alpha+\beta)}
-      \frac{\Gamma(\alpha+\beta)}{\Gamma(\alpha)\Gamma(\beta)}
-    */
-    Type logres =
-      lgamma(n + 1) - lgamma(y + 1)     - lgamma(n - y + 1) +
-      lgamma(y + a) + lgamma(n - y + b) - lgamma(n + a + b) +
-      lgamma(a + b) - lgamma(a)         - lgamma(b) ;
-    if(!give_log) return exp(logres);
-    else return logres;
-  }
-	
-  template<class Type>
-  Type dgenpois(Type y, Type theta, Type lambda, int give_log=0)
-  {
-    /*
-      f(y|\theta,\lambda) =
-      \frac{\theta(theta+\lambda y)^{y-1}e^{-\theta-\lambda y}}{y \!}
-    */
-    Type logres =
-      log(theta) + (y - 1) * log(theta + lambda * y) -
-      theta - lambda * y - lgamma(y + Type(1));
-    if(!give_log) return exp(logres);
-    else return logres;
-  }
-	
-  /* Simulate from generalized poisson distribution */
-  template<class Type>
-  Type rgenpois(Type theta, Type lambda) {
-    // Copied from R function HMMpa::rgenpois
-    Type ans = Type(0);
-    Type random_number = runif(Type(0), Type(1));
-    Type kum = dgenpois(Type(0), theta, lambda);
-    while (random_number > kum) {
-      ans = ans + Type(1);
-      kum += dgenpois(ans, theta, lambda);
-    }
-    return ans;
-  }
-	
-  /* Simulate from zero-truncated generalized poisson distribution */
-  template<class Type>
-  Type rtruncated_genpois(Type theta, Type lambda) {
-    int nloop = 10000;
-    int counter = 0;
-    Type ans = rgenpois(theta, lambda);
-    while(ans < Type(1) && counter < nloop) {
-      ans = rgenpois(theta, lambda);
-      counter++;
-    }
-    if(ans < 1.) warning("Zeros in simulation of zero-truncated data. Possibly due to low estimated mean.");
-    return ans;
-  }
-
-  template<class Type>
-  bool isNA(Type x){
-    return R_IsNA(asDouble(x));
-  }
-
-  extern "C" {
-    /* See 'R-API: entry points to C-code' (Writing R-extensions) */
-    double Rf_logspace_sub (double logx, double logy);
-    void   Rf_pnorm_both(double x, double *cum, double *ccum, int i_tail, int log_p);
-  }
-
-  /* y(x) = logit_invcloglog(x) := log( exp(exp(x)) - 1 ) = logspace_sub( exp(x), 0 )
-
-     y'(x) = exp(x) + exp(x-y) = exp( logspace_add(x, x-y) )
-
-   */
-  TMB_ATOMIC_VECTOR_FUNCTION(
-                             // ATOMIC_NAME
-                             logit_invcloglog
-                             ,
-                             // OUTPUT_DIM
-                             1,
-                             // ATOMIC_DOUBLE
-                             ty[0] = Rf_logspace_sub(exp(tx[0]), 0.);
-                             ,
-                             // ATOMIC_REVERSE
-                             px[0] = exp( logspace_add(tx[0], tx[0]-ty[0]) ) * py[0];
-                             )
-  template<class Type>
-  Type logit_invcloglog(Type x) {
-    CppAD::vector<Type> tx(1);
-    tx[0] = x;
-    return logit_invcloglog(tx)[0];
-  }
-
-  /* y(x) = logit_pnorm(x) := logit( pnorm(x) ) =
-     pnorm(x, lower.tail=TRUE,  log.p=TRUE) -
-     pnorm(x, lower.tail=FALSE, log.p=TRUE)
-
-     y'(x) = dnorm(x) * ( (1+exp(y)) + (1+exp(-y)) )
-
-  */
-  double logit_pnorm(double x) {
-    double log_p_lower, log_p_upper;
-    Rf_pnorm_both(x, &log_p_lower, &log_p_upper, 2 /* both tails */, 1 /* log_p */);
-    return log_p_lower - log_p_upper;
-  }
-  TMB_ATOMIC_VECTOR_FUNCTION(
-                             // ATOMIC_NAME
-                             logit_pnorm
-                             ,
-                             // OUTPUT_DIM
-                             1,
-                             // ATOMIC_DOUBLE
-                             ty[0] = logit_pnorm(tx[0])
-                             ,
-                             // ATOMIC_REVERSE
-                             Type zero = 0;
-                             Type tmp1 = logspace_add(zero, ty[0]);
-                             Type tmp2 = logspace_add(zero, -ty[0]);
-                             Type tmp3 = logspace_add(tmp1, tmp2);
-                             Type tmp4 = dnorm(tx[0], Type(0), Type(1), true) + tmp3;
-                             px[0] = exp( tmp4 ) * py[0];
-                             )
-  template<class Type>
-  Type logit_pnorm(Type x) {
-    CppAD::vector<Type> tx(1);
-    tx[0] = x;
-    return logit_pnorm(tx)[0];
-  }
-
-  /* Calculate variance in compois family using
-
-     V(X) = (logZ)''(loglambda)
-
-  */
-  double compois_calc_var(double mean, double nu){
-    using atomic::compois_utils::calc_loglambda;
-    using atomic::compois_utils::calc_logZ;
-    double loglambda = calc_loglambda(log(mean), nu);
-    typedef atomic::tiny_ad::variable<2, 1, double> ADdouble;
-    ADdouble loglambda_ (loglambda, 0);
-    ADdouble ans = calc_logZ<ADdouble>(loglambda_, nu);
-    return ans.getDeriv()[0];
-  }
-
-  /* Simulate from zero-truncated Conway-Maxwell-Poisson distribution */
-  template<class Type>
-  Type rtruncated_compois2(Type mean, Type nu) {
-    int nloop = 10000;
-    int counter = 0;
-    Type ans = rcompois2(mean, nu);
-    while(ans < 1. && counter < nloop) {
-      ans = rcompois2(mean, nu);
-      counter++;
-    }
-    if(ans < 1.) warning("Zeros in simulation of zero-truncated data. Possibly due to low estimated mean.");
-    return ans;
-  }
-
-  /* Simulate from tweedie distribution */
-  template<class Type>
-  Type rtweedie(Type mu, Type phi, Type p) {
-    // Copied from R function tweedie::rtweedie
-    Type lambda = pow(mu, 2. - p) / (phi * (2. - p));
-    Type alpha  = (2. - p) / (1. - p);
-    Type gam = phi * (p - 1.) * pow(mu, p - 1.);
-    int N = (int) asDouble(rpois(lambda));
-    Type ans = rgamma(N, -alpha /* shape */, gam /* scale */).sum();
-    return ans;
-  }
+template<class Type>
+bool isNA(Type x){
+  return R_IsNA(asDouble(x));
 }
 
-/* Interface to compois variance */
-extern "C" {
-  SEXP compois_calc_var(SEXP mean, SEXP nu) {
-    if (LENGTH(mean) != LENGTH(nu))
-      error("'mean' and 'nu' must be vectors of same length.");
-    SEXP ans = PROTECT(allocVector(REALSXP, LENGTH(mean)));
-    for(int i=0; i<LENGTH(mean); i++)
-      REAL(ans)[i] = glmmtmb::compois_calc_var(REAL(mean)[i], REAL(nu)[i]);
-    UNPROTECT(1);
-    return ans;
-  }
+template<class Type>
+bool notFinite(Type x) {
+  return (!R_FINITE(asDouble(x)));
 }
-
-/* Quantile functions needed to simulate from truncated distributions */
-extern "C" {
-  double Rf_qnbinom(double p, double size, double prob, int lower_tail, int log_p);
-  double Rf_qpois(double p, double lambda, int lower_tail, int log_p);
 }
 
 enum valid_family {
@@ -236,7 +55,8 @@ enum valid_covStruct {
   exp_covstruct = 5,
   gau_covstruct = 6,
   mat_covstruct = 7,
-  toep_covstruct = 8
+  toep_covstruct = 8,
+  rr_covstruct = 9
 };
 
 enum valid_ziPredictCode {
@@ -307,6 +127,9 @@ Type log_inverse_linkfun(Type eta, int link) {
   case log_link:
     ans = eta;
     break;
+  case logit_link:
+    ans = -logspace_add(Type(0), -eta);
+    break;
   default:
     ans = log( inverse_linkfun(eta, link) );
   } // End switch
@@ -325,6 +148,7 @@ struct per_term_info {
   // Report output
   matrix<Type> corr;
   vector<Type> sd;
+  matrix<Type> fact_load; // For rr case
 };
 
 template <class Type>
@@ -547,6 +371,44 @@ Type termwise_nll(array<Type> &U, vector<Type> theta, per_term_info<Type>& term,
     term.sd.resize(n);  // For report
     term.sd.fill(sd);
   }
+  else if (term.blockCode == rr_covstruct){
+    // case: reduced rank
+    for(int i = 0; i < term.blockReps; i++){
+      ans -= dnorm(vector<Type>(U.col(i)), Type(0), 1, true).sum();
+      if (do_simulate) {
+        U.col(i) = rnorm(U.rows(), Type(0), Type(1));
+      }
+    }
+
+    int p = term.blockSize;
+    int nt = theta.size();
+    int rank = (2*p + 1 -  (int)sqrt(pow(2.0*p + 1, 2) - 8*nt) ) / 2 ;
+    matrix<Type> Lambda(p, rank);
+    vector<Type> lam_diag = theta.head(rank);
+    vector<Type> lam_lower = theta.tail(nt - rank);
+    for (int j = 0; j < rank; j++){
+      for (int i = 0; i < p; i++){
+        if (j > i)
+          Lambda(i, j) = 0;
+        else if(i == j)
+          Lambda(i, j) = lam_diag(j);
+        else
+          Lambda(i, j) = lam_lower(j*p - (j + 1)*j/2 + i - 1 - j); //Fills by column
+      }
+    }
+
+    for(int i = 0; i < term.blockReps; i++){
+      vector<Type> usub = U.col(i).segment(0, rank);
+      U.col(i) = Lambda * usub;
+    }
+
+    term.fact_load = Lambda;
+    if(isDouble<Type>::value) {
+      term.corr = Lambda * Lambda.transpose();
+      term.sd = term.corr.diagonal().array().sqrt();
+      term.corr.array() /= term.sd * term.sd.transpose();
+    }
+  }
   else error("covStruct not implemented!");
   return ans;
 }
@@ -579,6 +441,13 @@ Type allterms_nll(vector<Type> &u, vector<Type> theta,
 template<class Type>
 Type objective_function<Type>::operator() ()
 {
+#ifdef _OPENMP
+  this -> max_parallel_regions = omp_get_max_threads();
+  // std::cout << "OpenMP max_parallel_regions=" << this -> max_parallel_regions << "\n";
+#else
+  this -> max_parallel_regions = 1;
+  // std::cout << "no OpenMP (max_parallel_regions=1)\n";
+#endif
 
   DATA_MATRIX(X);
   bool sparseX = X.rows()==0 && X.cols()==0;
@@ -623,16 +492,15 @@ Type objective_function<Type>::operator() ()
   bool zi_flag = (betazi.size() > 0);
   DATA_INTEGER(doPredict);
   DATA_IVECTOR(whichPredict);
-
   // One-Step-Ahead (OSA) residuals
   DATA_VECTOR_INDICATOR(keep, yobs);
 
   // Joint negative log-likelihood
-  parallel_accumulator<Type> jnll(this);
+  Type jnll=0;
 
   // Random effects
-  jnll += allterms_nll(b, theta, terms, this->do_simulate);
-  jnll += allterms_nll(bzi, thetazi, termszi, this->do_simulate);
+  PARALLEL_REGION jnll += allterms_nll(b, theta, terms, this->do_simulate);
+  PARALLEL_REGION jnll += allterms_nll(bzi, thetazi, termszi, this->do_simulate);
 
   // Linear predictor
   vector<Type> eta = Z * b + offset;
@@ -656,7 +524,7 @@ Type objective_function<Type>::operator() ()
     DATA_SPARSE_MATRIX(XdS);
     etad += XdS*betad;
   }
-  
+
   // Apply link
   vector<Type> mu(eta.size());
   for (int i = 0; i < mu.size(); i++)
@@ -673,7 +541,7 @@ Type objective_function<Type>::operator() ()
   // Observation likelihood
   Type s1, s2, s3, log_nzprob;
   Type tmp_loglik;
-  for (int i=0; i < yobs.size(); i++){
+  for (int i=0; i < yobs.size(); i++) PARALLEL_REGION {
     if ( !glmmtmb::isNA(yobs(i)) ) {
       switch (family) {
       case gaussian_family:
@@ -703,11 +571,15 @@ Type objective_function<Type>::operator() ()
         SIMULATE{yobs(i) = rbeta(s1, s2);}
         break;
       case betabinomial_family:
-        s1 = mu(i)*phi(i); // s1 = mu(i) * mu(i) / phi(i);
-        s2 = (Type(1)-mu(i))*phi(i); // phi(i) / mu(i);
-        tmp_loglik = glmmtmb::dbetabinom(yobs(i), s1, s2, size(i), true);
+        // Transform to logit scale independent of link
+        s3 = logit_inverse_linkfun(eta(i), link); // logit(p)
+        // Was: s1 = mu(i) * phi(i);
+        s1 = log_inverse_linkfun( s3, logit_link) + log(phi(i)); // s1 = log(mu*phi)
+        // Was: s2 = (Type(1) - mu(i)) * phi(i);
+        s2 = log_inverse_linkfun(-s3, logit_link) + log(phi(i)); // s2 = log((1-mu)*phi)
+        tmp_loglik = glmmtmb::dbetabinom_robust(yobs(i), s1, s2, size(i), true);
         SIMULATE {
-          yobs(i) = rbinom(size(i), rbeta(s1, s2) );
+          yobs(i) = rbinom(size(i), rbeta(exp(s1), exp(s2)) );
         }
         break;
       case nbinom1_family:
@@ -719,30 +591,25 @@ Type objective_function<Type>::operator() ()
         s1 = log_inverse_linkfun(eta(i), link);          // log(mu)
         s2 = s1 + etad(i) ;                              // log(var - mu)
         tmp_loglik = dnbinom_robust(yobs(i), s1, s2, true);
-        SIMULATE {
-          s1 = mu(i);
-          s2 = mu(i) * (Type(1)+phi(i));  // (1+phi) guarantees that var >= mu
-          yobs(i) = rnbinom2(s1, s2);
-        }
-        if( family == truncated_nbinom1_family ) {
-          // s3 := log( 1. + phi(i) )
-          s3 = logspace_add( Type(0), etad(i) );
+	if (family != truncated_nbinom1_family) {
+		SIMULATE {
+			s1 = mu(i);
+			s2 = mu(i) * (Type(1)+phi(i));  // (1+phi) guarantees that var >= mu
+			yobs(i) = rnbinom2(s1, s2);
+		}
+	} else {
+          s3 = logspace_add( Type(0), etad(i) );                // log(1. + phi(i)
           log_nzprob = logspace_sub( Type(0), -mu(i) / phi(i) * s3 ); // 1-prob(0)
           tmp_loglik -= log_nzprob;
 	  tmp_loglik = zt_lik_nearzero(yobs(i), tmp_loglik);
           SIMULATE{
-            s1 = mu(i)/phi(i);//sz
-            s2 = 1/(1+phi(i)); //pb
-            yobs(i) = Rf_qnbinom(asDouble(runif(dnbinom(Type(0), s1, s2), Type(1))), asDouble(s1), asDouble(s2), 1, 0);
+            s1 = mu(i)/phi(i); //sz
+	    yobs(i) = glmmtmb::rtruncated_nbinom(asDouble(s1), 0, asDouble(mu(i)));
           }
         }
         break;
       case nbinom2_family:
       case truncated_nbinom2_family:
-        // Was:
-        //   s1 = mu(i);
-        //   s2 = mu(i) * (Type(1) + mu(i) / phi(i));
-        //   tmp_loglik = dnbinom2(yobs(i), s1, s2, true);
         s1 = log_inverse_linkfun(eta(i), link);          // log(mu)
         s2 = 2. * s1 - etad(i) ;                         // log(var - mu)
         tmp_loglik = dnbinom_robust(yobs(i), s1, s2, true);
@@ -758,25 +625,16 @@ Type objective_function<Type>::operator() ()
           tmp_loglik -= log_nzprob;
           tmp_loglik = zt_lik_nearzero( yobs(i), tmp_loglik);
           SIMULATE{
-            s1 = phi(i); //sz
-            s2 = phi(i)/(phi(i)+mu(i)); //pb
-            yobs(i) = Rf_qnbinom(asDouble(runif(dnbinom(Type(0), s1, s2), Type(1))), asDouble(s1), asDouble(s2), 1, 0);
+		  yobs(i) = glmmtmb::rtruncated_nbinom(asDouble(phi(i)), 0, asDouble(mu(i)));
           }
         }
         break;
       case truncated_poisson_family:
-        // Was:
-        //   if (mu(i)<1e-6) {
-        //     nzprob = mu(i)*(1-mu(i)/2);
-        //   } else {
-        //     nzprob = 1-exp(-mu(i));
-        //   }
-        // log(nzprob) = log( 1 - exp(-mu(i)) )
-        log_nzprob = logspace_sub(Type(0), -mu(i));
+        log_nzprob = logspace_sub(Type(0), -mu(i));  // log(1-exp(-mu(i))) = P(x>0)
         tmp_loglik = dpois(yobs(i), mu(i), true) - log_nzprob;
         tmp_loglik = zt_lik_nearzero(yobs(i), tmp_loglik);
         SIMULATE{
-          yobs(i) = Rf_qpois(asDouble(runif(dpois(Type(0), mu(i)), Type(1))), asDouble(mu(i)), 1, 0);
+		yobs(i) = glmmtmb::rtruncated_poisson(0, asDouble(mu(i)));
         }
         break;
      case genpois_family:
@@ -862,10 +720,19 @@ Type objective_function<Type>::operator() ()
     }
   }
 
+  vector<matrix<Type> > fact_load(terms.size());
+  for(int i=0; i<terms.size(); i++){
+    // NOTE: Dummy terms reported as empty
+    if(terms(i).blockNumTheta > 0){
+      fact_load(i) = terms(i).fact_load;
+    }
+  }
+
   REPORT(corr);
   REPORT(sd);
   REPORT(corrzi);
   REPORT(sdzi);
+  REPORT(fact_load);
   SIMULATE {
     REPORT(yobs);
     REPORT(b);
@@ -893,7 +760,8 @@ Type objective_function<Type>::operator() ()
       //mu = mu; // Predict mean of 'family' //comented out for clang 7.0.0. with no effect
       break;
     case prob_zipredictcode:
-      mu = pz; // Predict zi probability
+      mu = pz;     // Predict zi probability
+      eta = etazi; // want to return linear pred for zi
       break;
     default:
       error("Invalid 'ziPredictCode'");
@@ -902,11 +770,18 @@ Type objective_function<Type>::operator() ()
 
   whichPredict -= 1; // R-index -> C-index
   vector<Type> mu_predict = mu(whichPredict);
+  vector<Type> eta_predict = eta(whichPredict);
   REPORT(mu_predict);
-  // ADREPORT expensive for long vectors - only needed by predict()
-  // method.
-  if (doPredict) ADREPORT(mu_predict);
+  REPORT(eta_predict);
+  // ADREPORT expensive for long vectors - only needed by predict() method
+  if (doPredict==1) {
+	  ADREPORT(mu_predict);
+  } else if (doPredict == 2) {
+	  ADREPORT(eta_predict);
+  }
 
   return jnll;
 }
 
+
+
